
# Type: narrative text


A string that provides a human-readable description of something

URI: [biolink:NarrativeText](https://w3id.org/biolink/vocab/NarrativeText)

|  |  |  |
| --- | --- | --- |
| Parent type | | [String](types/String.md) |
| Root (builtin) type | | **str** |
